@@ -237,7 +237,7 @@ class VariableOsInstallNetMac(NetHelper,ReadonlyVariable):
         self.label = _("MAC")
 
     def get(self):
-        return map(lambda x:getMac(x),
+        return map(lambda x:getMac(x).lower(),
                self.Get('os_install_net_interfaces'))
 
 class VariableOsInstallNetStatus(NetHelper,Variable):
